#ifndef DNSSECCHECKVERSION_H
#define DNSSECCHECKVERSION_H

#define DNSSEC_CHECK_VERSION "2.1"

#endif // DNSSECCHECKVERSION_H
